.. _examples:

===============
Examples
===============

*Write script to walk the module tree, parse example content
from docstrings, autogenerate literalincludes directive, and
reproduce the content here.*
